.. include:: definitions.txt


Job execution
---------------

|towrite|


Case studies:

- write something at the prompt

Events: ::

 console init

 
 job iteration
 job status changed      host  job_id timestamp  old_status  new_status

 host failed

 started 
 'command failed'
 'command interrupted'
 'command succeeded'    

 config changed